=======
Credits
=======

Development Lead
----------------

* Eric J. Ma <ericmajinglong@gmail.com>

Contributors
------------

* Nora Kassner <nora.kassner@t-online.de>
* Christian Diener <mail (at) cdiener.com>
* Thijs Hermans <hermansthijs91@gmail.com>
* R. M. Keelan Downton <keelan.downton@gmail.com>
